//
//  IODItem.m
//  iOSDiner
//
//  Created by Adam Burkepile on 1/29/12.
//  Copyright (c) 2012 Adam Burkepile. All rights reserved.
//  Edited by Chris LaPollo on 3/5/13
//  Copyright (c) 2012 Chris LaPollo. All rights reserved.

#import "IODItem.h"
#define kInventoryAddress @"http://adamburkepile.com/inventory/"

@implementation IODItem

@synthesize name;
@synthesize price;
@synthesize pictureFile;

- (id)initWithName:(NSString*)inName andPrice:(float)inPrice andPictureFile:(NSString*)inPictureFile {
    if (self = [self init]) {
        [self setName:inName];
        [self setPrice:inPrice];
        [self setPictureFile:inPictureFile];
    }
    
    return self;
}

-(id)copyWithZone:(NSZone *)zone {
    IODItem* newItem = [IODItem new];
    [newItem setName:[self name]];
    [newItem setPrice:[self price]];
    [newItem setPictureFile:[self pictureFile]];
    
    return newItem;
}

+ (NSArray*)retrieveInventoryItems {
    NSMutableArray* inventory = [NSMutableArray new];
    NSError* err = nil;
    
    NSArray* jsonInventory = [NSJSONSerialization JSONObjectWithData:[NSData dataWithContentsOfURL:[NSURL URLWithString:kInventoryAddress]] 
                                                             options:kNilOptions 
                                                               error:&err];
    [jsonInventory enumerateObjectsUsingBlock:^(id obj, NSUInteger idx, BOOL *stop) {
        NSDictionary* item = obj;
        [inventory addObject:[[IODItem alloc] initWithName:[item objectForKey:@"Name"] 
                                                  andPrice:[[item objectForKey:@"Price"] floatValue]
                                            andPictureFile:[item objectForKey:@"Image"]]];
    }];
    
    return [inventory copy];
}

// necessary to use these objects as keys in a dictionary
- (BOOL)isEqual:(id)other
{
  if (other == self)
    return YES;
  if (!other || ![other isKindOfClass:[self class]])
    return NO;
  else
  {
    IODItem* otherI = (IODItem*)other;
    if (![self.name isEqualToString:otherI.name])
      return NO;
    if (self.price != otherI.price)
      return NO;
    return YES;
  }
}

// necessary to use these objects as keys in a dictionary
- (NSUInteger)hash
{
  NSUInteger prime = 31;
  NSUInteger result = prime + [self.name hash];
  result = prime * result + self.price;
  return result;
}

@end
